Paginator

Struct Paginator 

#[non_exhaustive]
pub struct Paginator<T> { pub count: Option<u64>, pub items: Vec<T>, pub ctoken: Option<String>, pub visitor_data: Option<String>, pub endpoint: ContinuationEndpoint, pub authenticated: bool, }
Wrapper around progressively fetched items

The paginator is a wrapper around a list of items that are fetched in pages from the YouTube API (e.g. playlist items, video recommendations or comments).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
count: Option<u64>

Total number of items if finite and known.

Note that this number may not be 100% accurate, as this is the number returned by the YouTube API at the initial fetch.

It is intended to be shown to the user (e.g. 1261 comments, 18 Videos) and for progress estimation.

Don’t use this number to check if all items were fetched or for iterating over the items.

items: Vec<T>

Content of the paginator

ctoken: Option<String>

The continuation token is passed to the YouTube API to fetch more items.

If it is None, it means that no more items can be fetched.

visitor_data: Option<String>

YouTube visitor data. Required for fetching the startpage

endpoint: ContinuationEndpoint

YouTube API endpoint to fetch continuations from

authenticated: bool

True if the paginator should be fetched with YouTube credentials

Implementations

Source

impl<T: FromYtItem> Paginator<T>

pub async fn next<Q: AsRef<RustyPipeQuery>>( &self, query: Q, ) -> Result<Option<Self>, Error>

Get the next page from the paginator (or None if the paginator is exhausted)

pub async fn extend<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, ) -> Result<bool, Error>

Extend the items of the paginator by the next page

Returns false if the paginator is exhausted.

pub async fn extend_pages<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, n_pages: usize, ) -> Result<(), Error>

Extend the items of the paginator by the given amount of pages or until the paginator is exhausted.

pub async fn extend_limit<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, n_items: usize, ) -> Result<(), Error>

Extend the items of the paginator until the given amount of items is reached or the paginator is exhausted.

pub async fn extend_all<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, ) -> Result<(), Error>

Extend the items of the paginator until the paginator is exhausted.

Source

impl Paginator<Comment>

pub async fn next<Q: AsRef<RustyPipeQuery>>( &self, query: Q, ) -> Result<Option<Self>, Error>

Get the next page from the paginator (or None if the paginator is exhausted)

Source

impl Paginator<HistoryItem<VideoItem>>

pub async fn next<Q: AsRef<RustyPipeQuery>>( &self, query: Q, ) -> Result<Option<Self>, Error>

Available on crate feature userdata only.

Get the next page from the paginator (or None if the paginator is exhausted)

Source

impl Paginator<HistoryItem<TrackItem>>

pub async fn next<Q: AsRef<RustyPipeQuery>>( &self, query: Q, ) -> Result<Option<Self>, Error>

Available on crate feature userdata only.

Get the next page from the paginator (or None if the paginator is exhausted)

Source

impl Paginator<Comment>

pub async fn extend<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, ) -> Result<bool, Error>

Extend the items of the paginator by the next page

Returns false if the paginator is exhausted.

pub async fn extend_pages<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, n_pages: usize, ) -> Result<(), Error>

Extend the items of the paginator by the given amount of pages or until the paginator is exhausted.

pub async fn extend_limit<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, n_items: usize, ) -> Result<(), Error>

Extend the items of the paginator until the given amount of items is reached or the paginator is exhausted.

pub async fn extend_all<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, ) -> Result<(), Error>

Extend the items of the paginator until the paginator is exhausted.

Source

impl Paginator<HistoryItem<VideoItem>>

pub async fn extend<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, ) -> Result<bool, Error>

Extend the items of the paginator by the next page

Returns false if the paginator is exhausted.

pub async fn extend_pages<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, n_pages: usize, ) -> Result<(), Error>

Extend the items of the paginator by the given amount of pages or until the paginator is exhausted.

pub async fn extend_limit<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, n_items: usize, ) -> Result<(), Error>

Extend the items of the paginator until the given amount of items is reached or the paginator is exhausted.

pub async fn extend_all<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, ) -> Result<(), Error>

Extend the items of the paginator until the paginator is exhausted.

Source

impl Paginator<HistoryItem<TrackItem>>

pub async fn extend<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, ) -> Result<bool, Error>

Extend the items of the paginator by the next page

Returns false if the paginator is exhausted.

pub async fn extend_pages<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, n_pages: usize, ) -> Result<(), Error>

Extend the items of the paginator by the given amount of pages or until the paginator is exhausted.

pub async fn extend_limit<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, n_items: usize, ) -> Result<(), Error>

Extend the items of the paginator until the given amount of items is reached or the paginator is exhausted.

pub async fn extend_all<Q: AsRef<RustyPipeQuery>>( &mut self, query: Q, ) -> Result<(), Error>

Extend the items of the paginator until the paginator is exhausted.

Source

impl<T> Paginator<T>

pub fn is_exhausted(&self) -> bool

Check if the paginator is exhausted, meaning that no more items can be fetched.

Equivalent to paginator.ctoken.is_none().

pub fn is_empty(&self) -> bool

Check if the paginator does not contain any data, meaning that it is exhausted and does not contain any items.