#[non_exhaustive]pub struct MusicSearchResult<T> {
pub items: Paginator<T>,
pub corrected_query: Option<String>,
}Expand description
YouTube Music search result
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.items: Paginator<T>Search items
corrected_query: Option<String>Corrected search query
If the search term containes a typo, YouTube instead searches for the corrected search term and displays it on top of the search results page.