#[non_exhaustive]pub struct TrackItem {
pub id: String,
pub name: String,
pub duration: Option<u32>,
pub cover: Vec<Thumbnail>,
pub artists: Vec<ArtistId>,
pub artist_id: Option<String>,
pub album: Option<AlbumId>,
pub view_count: Option<u64>,
pub track_type: TrackType,
pub track_nr: Option<u16>,
pub by_va: bool,
}Expand description
YouTube Music track list item
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringUnique YouTube video ID
name: StringTrack name
duration: Option<u32>Track duration in seconds
None when extracted from an artist page or a featured video.
cover: Vec<Thumbnail>Album cover
artists: Vec<ArtistId>Artists of the track
artist_id: Option<String>Primary artist ID
album: Option<AlbumId>Album of the track
view_count: Option<u64>View count
None if it is a not a video or the view count could not be extracted.
track_type: TrackTypeType of the track (YTM track / music video / podcast episode)
track_nr: Option<u16>Album track number
None if the track is not fetched from an album.
by_va: boolIs the track by ‘Various artists’?